@@ -3,7 +3,7 @@ from datetime import datetime, timedelta
 import logging
 import re
 
-from env_canada import ECData
+from env_canada import ECData  # pylint: disable=import-error
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
