@@ -69,15 +69,11 @@ class NetatmoFlowHandler(
         """Handle a flow start."""
         await self.async_set_unique_id(DOMAIN)
 
-        if self.hass.config_entries.async_entries(DOMAIN):
+        if self._async_current_entries():
             return self.async_abort(reason="single_instance_allowed")
 
         return await super().async_step_user(user_input)
 
-    async def async_step_homekit(self, homekit_info):
-        """Handle HomeKit discovery."""
-        return await self.async_step_user()
-
 
 class NetatmoOptionsFlowHandler(config_entries.OptionsFlow):
     """Handle Netatmo options."""
@@ -108,20 +104,23 @@ class NetatmoOptionsFlowHandler(config_entries.OptionsFlow):
                     user_input={CONF_NEW_AREA: new_client}
                 )
 
-            return self._update_options()
+            return self._create_options_entry()
 
         weather_areas = list(self.options[CONF_WEATHER_AREAS])
 
         data_schema = vol.Schema(
             {
                 vol.Optional(
-                    CONF_WEATHER_AREAS, default=weather_areas,
+                    CONF_WEATHER_AREAS,
+                    default=weather_areas,
                 ): cv.multi_select(weather_areas),
                 vol.Optional(CONF_NEW_AREA): str,
             }
         )
         return self.async_show_form(
-            step_id="public_weather_areas", data_schema=data_schema, errors=errors,
+            step_id="public_weather_areas",
+            data_schema=data_schema,
+            errors=errors,
         )
 
     async def async_step_public_weather(self, user_input=None):
@@ -173,17 +172,19 @@ class NetatmoOptionsFlowHandler(config_entries.OptionsFlow):
                     ),
                 ): cv.longitude,
                 vol.Required(
-                    CONF_PUBLIC_MODE, default=orig_options.get(CONF_PUBLIC_MODE, "avg"),
+                    CONF_PUBLIC_MODE,
+                    default=orig_options.get(CONF_PUBLIC_MODE, "avg"),
                 ): vol.In(["avg", "max"]),
                 vol.Required(
-                    CONF_SHOW_ON_MAP, default=orig_options.get(CONF_SHOW_ON_MAP, False),
+                    CONF_SHOW_ON_MAP,
+                    default=orig_options.get(CONF_SHOW_ON_MAP, False),
                 ): bool,
             }
         )
 
         return self.async_show_form(step_id="public_weather", data_schema=data_schema)
 
-    def _update_options(self):
+    def _create_options_entry(self):
         """Update config entry options."""
         return self.async_create_entry(
             title="Netatmo Public Weather", data=self.options
