@@ -1,8 +1,10 @@
 """Support for Tesla cars."""
 import asyncio
 from collections import defaultdict
+from datetime import timedelta
 import logging
 
+import async_timeout
 from teslajsonpy import Controller as TeslaAPI, TeslaException
 import voluptuous as vol
 
@@ -17,8 +19,13 @@ from homeassistant.const import (
     CONF_USERNAME,
 )
 from homeassistant.core import callback
+from homeassistant.exceptions import ConfigEntryNotReady
 from homeassistant.helpers import aiohttp_client, config_validation as cv
-from homeassistant.helpers.entity import Entity
+from homeassistant.helpers.update_coordinator import (
+    CoordinatorEntity,
+    DataUpdateCoordinator,
+    UpdateFailed,
+)
 from homeassistant.util import slugify
 
 from .config_flow import (
@@ -116,7 +123,6 @@ async def async_setup(hass, base_config):
 
 async def async_setup_entry(hass, config_entry):
     """Set up Tesla as config entry."""
-
     hass.data.setdefault(DOMAIN, {})
     config = config_entry.data
     websession = aiohttp_client.async_get_clientsession(hass)
@@ -145,13 +151,22 @@ async def async_setup_entry(hass, config_entry):
         _LOGGER.error("Unable to communicate with Tesla API: %s", ex.message)
         return False
     _async_save_tokens(hass, config_entry, access_token, refresh_token)
+    coordinator = TeslaDataUpdateCoordinator(
+        hass, config_entry=config_entry, controller=controller
+    )
+    # Fetch initial data so we have data when entities subscribe
     entry_data = hass.data[DOMAIN][config_entry.entry_id] = {
-        "controller": controller,
+        "coordinator": coordinator,
         "devices": defaultdict(list),
         DATA_LISTENER: [config_entry.add_update_listener(update_listener)],
     }
     _LOGGER.debug("Connected to the Tesla API")
-    all_devices = entry_data["controller"].get_homeassistant_components()
+
+    await coordinator.async_refresh()
+    if not coordinator.last_update_success:
+        raise ConfigEntryNotReady
+
+    all_devices = controller.get_homeassistant_components()
 
     if not all_devices:
         return False
@@ -169,44 +184,82 @@ async def async_setup_entry(hass, config_entry):
 
 async def async_unload_entry(hass, config_entry) -> bool:
     """Unload a config entry."""
-    await asyncio.gather(
-        *[
-            hass.config_entries.async_forward_entry_unload(config_entry, component)
-            for component in TESLA_COMPONENTS
-        ]
+    unload_ok = all(
+        await asyncio.gather(
+            *[
+                hass.config_entries.async_forward_entry_unload(config_entry, component)
+                for component in TESLA_COMPONENTS
+            ]
+        )
     )
     for listener in hass.data[DOMAIN][config_entry.entry_id][DATA_LISTENER]:
         listener()
     username = config_entry.title
-    hass.data[DOMAIN].pop(config_entry.entry_id)
-    _LOGGER.debug("Unloaded entry for %s", username)
-    return True
+    if unload_ok:
+        hass.data[DOMAIN].pop(config_entry.entry_id)
+        _LOGGER.debug("Unloaded entry for %s", username)
+        return True
+    return False
 
 
 async def update_listener(hass, config_entry):
     """Update when config_entry options update."""
-    controller = hass.data[DOMAIN][config_entry.entry_id]["controller"]
+    controller = hass.data[DOMAIN][config_entry.entry_id]["coordinator"].controller
     old_update_interval = controller.update_interval
     controller.update_interval = config_entry.options.get(CONF_SCAN_INTERVAL)
-    _LOGGER.debug(
-        "Changing scan_interval from %s to %s",
-        old_update_interval,
-        controller.update_interval,
-    )
+    if old_update_interval != controller.update_interval:
+        _LOGGER.debug(
+            "Changing scan_interval from %s to %s",
+            old_update_interval,
+            controller.update_interval,
+        )
 
 
-class TeslaDevice(Entity):
-    """Representation of a Tesla device."""
+class TeslaDataUpdateCoordinator(DataUpdateCoordinator):
+    """Class to manage fetching Tesla data."""
 
-    def __init__(self, tesla_device, controller, config_entry):
-        """Initialise the Tesla device."""
-        self.tesla_device = tesla_device
+    def __init__(self, hass, *, config_entry, controller):
+        """Initialize global Tesla data updater."""
         self.controller = controller
         self.config_entry = config_entry
+
+        update_interval = timedelta(seconds=MIN_SCAN_INTERVAL)
+
+        super().__init__(
+            hass,
+            _LOGGER,
+            name=DOMAIN,
+            update_interval=update_interval,
+        )
+
+    async def _async_update_data(self):
+        """Fetch data from API endpoint."""
+        if self.controller.is_token_refreshed():
+            (refresh_token, access_token) = self.controller.get_tokens()
+            _async_save_tokens(
+                self.hass, self.config_entry, access_token, refresh_token
+            )
+            _LOGGER.debug("Saving new tokens in config_entry")
+
+        try:
+            # Note: asyncio.TimeoutError and aiohttp.ClientError are already
+            # handled by the data update coordinator.
+            async with async_timeout.timeout(30):
+                return await self.controller.update()
+        except TeslaException as err:
+            raise UpdateFailed(f"Error communicating with API: {err}") from err
+
+
+class TeslaDevice(CoordinatorEntity):
+    """Representation of a Tesla device."""
+
+    def __init__(self, tesla_device, coordinator):
+        """Initialise the Tesla device."""
+        super().__init__(coordinator)
+        self.tesla_device = tesla_device
         self._name = self.tesla_device.name
-        self.tesla_id = slugify(self.tesla_device.uniq_name)
-        self._attributes = {}
-        self._icon = ICONS.get(self.tesla_device.type)
+        self._unique_id = slugify(self.tesla_device.uniq_name)
+        self._attributes = self.tesla_device.attrs.copy()
 
     @property
     def name(self):
@@ -216,7 +269,7 @@ class TeslaDevice(Entity):
     @property
     def unique_id(self) -> str:
         """Return a unique ID."""
-        return self.tesla_id
+        return self._unique_id
 
     @property
     def icon(self):
@@ -224,17 +277,12 @@ class TeslaDevice(Entity):
         if self.device_class:
             return None
 
-        return self._icon
-
-    @property
-    def should_poll(self):
-        """Return the polling state."""
-        return self.tesla_device.should_poll
+        return ICONS.get(self.tesla_device.type)
 
     @property
     def device_state_attributes(self):
         """Return the state attributes of the device."""
-        attr = self._attributes
+        attr = self._attributes.copy()
         if self.tesla_device.has_battery():
             attr[ATTR_BATTERY_LEVEL] = self.tesla_device.battery_level()
             attr[ATTR_BATTERY_CHARGING] = self.tesla_device.battery_charging()
@@ -253,16 +301,13 @@ class TeslaDevice(Entity):
 
     async def async_added_to_hass(self):
         """Register state update callback."""
+        self.async_on_remove(self.coordinator.async_add_listener(self.refresh))
 
-    async def async_will_remove_from_hass(self):
-        """Prepare for unload."""
+    @callback
+    def refresh(self) -> None:
+        """Refresh the state of the device.
 
-    async def async_update(self):
-        """Update the state of the device."""
-        if self.controller.is_token_refreshed():
-            (refresh_token, access_token) = self.controller.get_tokens()
-            _async_save_tokens(
-                self.hass, self.config_entry, access_token, refresh_token
-            )
-            _LOGGER.debug("Saving new tokens in config_entry")
-        await self.tesla_device.async_update()
+        This assumes the coordinator has updated the controller.
+        """
+        self.tesla_device.refresh()
+        self.async_write_ha_state()
