@@ -6,7 +6,7 @@ from twitch import TwitchClient
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA
-from homeassistant.const import CONF_TOKEN
+from homeassistant.const import CONF_CLIENT_ID, CONF_TOKEN
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity import Entity
 
@@ -23,7 +23,6 @@ ATTR_FOLLOWING = "followers"
 ATTR_VIEWS = "views"
 
 CONF_CHANNELS = "channels"
-CONF_CLIENT_ID = "client_id"
 
 ICON = "mdi:twitch"
 
